ElementMetadata class

Implementers

Constructors

ElementMetadata({required String name, required String importUri})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
importUri String
The import uri of the file that contains the element.
final
name String
The name of the element.
final
package String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited