UseCaseMetadata class

Contains metadata about elements annotated with UseCase.

Inheritance

Constructors

UseCaseMetadata({required String functionName, required String? designLink, required String name, required String importUri, required ElementMetadata component, required String navPath, required bool cloudExclude, required Map<String, dynamic>? knobsConfigs})
const
UseCaseMetadata.fromJson(Map<String, dynamic> json)
factory

Properties

cloudExclude bool
Whether the UseCase should be excluded from cloud builds.
final
component ElementMetadata
Metadata about the component that contains the UseCase.
final
URL to Figma's design file as defined in UseCase.designLink.
final
functionName String
The name of the UseCase-annotated function.
final
hashCode int
The hash code for this object.
no setterinherited
importUri String
The import uri of the file that contains the element.
finalinherited
knobsConfigs Map<String, dynamic>?
final
name String
The name of the element.
finalinherited
The path this element is placed under in the rendered widgetbook.
final
package String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited