WidgetbookInstance class
Properties
-
awaited
→ Expression
-
This expression preceded by
await.
no setterinherited
-
code
→ Code
-
The expression as a valid
Code block.
no setterinherited
-
expression
→ Expression
-
May be overridden to support other types implementing
Expression.
no setterinherited
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
isConst
→ bool
-
finalinherited
-
name
→ String?
-
finalinherited
-
namedArguments
→ Map<String, Expression>
-
finalinherited
-
nullChecked
→ Expression
-
Applies the null check operator on this expression, returning
this !.
no setterinherited
-
nullSafeSpread
→ Expression
-
This expression preceded by the null safe spread operator
?....
no setterinherited
-
parenthesized
→ ParenthesizedExpression
-
Returns this expression wrapped in parenthesis.
no setterinherited
-
positionalArguments
→ List<Expression>
-
finalinherited
-
returned
→ Expression
-
This expression preceded by
return.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
spread
→ Expression
-
This expression preceded by the spread operator
....
no setterinherited
-
statement
→ Code
-
The expression as a valid
Code block with a trailing ;.
no setterinherited
-
target
→ Expression
-
Target of the method invocation.
finalinherited
-
thrown
→ Expression
-
This expression preceded by
throw.
no setterinherited
-
type
→ InvokeExpressionType?
-
Optional; type of invocation.
finalinherited
-
typeArguments
→ List<Reference>
-
finalinherited
Methods
-
accept<R>(covariant ExpressionVisitor<R> visitor, [R? context])
→ R
-
inherited
-
addAssign(Expression other)
→ Expression
-
Return
this += other.
inherited
-
and(Expression other)
→ Expression
-
Returns the result of
this && other.
inherited
-
asA(Expression other)
→ Expression
-
Returns the result of
this as other.
inherited
-
assign(Expression other)
→ Expression
-
Return
{this} = {other}.
inherited
-
assignConst(String name, [Reference? type])
→ Expression
-
Return
const {name} = {this}.
inherited
-
assignFinal(String name, [Reference? type])
→ Expression
-
Return
final {name} = {this}.
inherited
-
assignNullAware(Expression other)
→ Expression
-
Return
{this} ??= {other}.
inherited
-
assignVar(String name, [Reference? type])
→ Expression
-
Return
var {name} = {this}.
inherited
-
bitwiseAndAssign(Expression other)
→ Expression
-
Return
this &= other.
inherited
-
bitwiseOrAssign(Expression other)
→ Expression
-
Return
this |= other.
inherited
-
bitwiseXorAssign(Expression other)
→ Expression
-
Return
this ^= other.
inherited
-
call(Iterable<Expression> positionalArguments, [Map<String, Expression> namedArguments = const {}, List<Reference> typeArguments = const []])
→ Expression
-
Call this expression as a method.
inherited
-
cascade(String name)
→ Expression
-
Returns an expression accessing
..<name> on this expression.
inherited
-
conditional(Expression whenTrue, Expression whenFalse)
→ Expression
-
inherited
-
divideAssign(Expression other)
→ Expression
-
Return
this /= other.
inherited
-
equalTo(Expression other)
→ Expression
-
Returns the result of
this == other.
inherited
-
euclideanModuloAssign(Expression other)
→ Expression
-
Return
this %= other.
inherited
-
greaterOrEqualTo(Expression other)
→ Expression
-
Returns the result of
this >= other.
inherited
-
greaterThan(Expression other)
→ Expression
-
Returns the result of
this > other.
inherited
-
ifNullThen(Expression other)
→ Expression
-
Return
{this} ?? {other}.
inherited
-
index(Expression index)
→ Expression
-
Returns accessing the index operator (
[]) on this.
inherited
-
intDivideAssign(Expression other)
→ Expression
-
Return
this ~/= other.
inherited
-
isA(Expression other)
→ Expression
-
Returns the result of
this is other.
inherited
-
isNotA(Expression other)
→ Expression
-
Returns the result of
this is! other.
inherited
-
lessOrEqualTo(Expression other)
→ Expression
-
Returns the result of
this <= other.
inherited
-
lessThan(Expression other)
→ Expression
-
Returns the result of
this < other.
inherited
-
multiplyAssign(Expression other)
→ Expression
-
Return
this *= other.
inherited
-
negate()
→ Expression
-
Returns the result of
!this.
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
notEqualTo(Expression other)
→ Expression
-
Returns the result of
this != other.
inherited
-
nullSafeProperty(String name)
→ Expression
-
Returns an expression accessing
?.<name> on this expression.
inherited
-
operatorAdd(Expression other)
→ Expression
-
Returns the result of
this + other.
inherited
-
operatorBitwiseAnd(Expression other)
→ Expression
-
Returns the result of
this & other.
inherited
-
operatorBitwiseOr(Expression other)
→ Expression
-
Returns the result of
this | other.
inherited
-
operatorBitwiseXor(Expression other)
→ Expression
-
Returns the result of
this ^ other.
inherited
-
operatorDivide(Expression other)
→ Expression
-
Returns the result of
this / other.
inherited
-
operatorEuclideanModulo(Expression other)
→ Expression
-
Returns the result of
this % other.
inherited
-
operatorIntDivide(Expression other)
→ Expression
-
Returns the result of
this ~/ other.
inherited
-
operatorMultiply(Expression other)
→ Expression
-
Returns the result of
this * other.
inherited
-
operatorShiftLeft(Expression other)
→ Expression
-
Returns the result of
this << other.
inherited
-
operatorShiftRight(Expression other)
→ Expression
-
Returns the result of
this >> other.
inherited
-
operatorShiftRightUnsigned(Expression other)
→ Expression
-
Returns the result of
this >>> other.
inherited
-
operatorSubstract(Expression other)
→ Expression
-
inherited
-
operatorSubtract(Expression other)
→ Expression
-
Returns the result of
this - other.
inherited
-
operatorUnaryBitwiseComplement()
→ Expression
-
Returns the result of
~this.
inherited
-
operatorUnaryMinus()
→ Expression
-
Returns the result of
-this.
inherited
-
operatorUnaryPostfixDecrement()
→ Expression
-
Return the result of
this--.
inherited
-
operatorUnaryPostfixIncrement()
→ Expression
-
Return the result of
this++.
inherited
-
operatorUnaryPrefixDecrement()
→ Expression
-
Returns the result of
--this.
inherited
-
operatorUnaryPrefixIncrement()
→ Expression
-
Returns the result of
++this.
inherited
-
or(Expression other)
→ Expression
-
Returns the result of
this || other.
inherited
-
property(String name)
→ Expression
-
Returns an expression accessing
.<name> on this expression.
inherited
-
shiftLeftAssign(Expression other)
→ Expression
-
Return
this <<= other.
inherited
-
shiftRightAssign(Expression other)
→ Expression
-
Return
this >>= other.
inherited
-
shiftRightUnsignedAssign(Expression other)
→ Expression
-
Return
this >>>= other.
inherited
-
subtractAssign(Expression other)
→ Expression
-
Return
this -= other.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited